<template>
  <SidebarLayout :navigation="navigation">
    <slot />
    <template #bottom>
      <template v-if="hasPermission(Permission.ADMIN_ANALYTICS)">
        <ul
          class="-mx-2 mb-4 mt-auto space-y-1"
          role="list"
        >
          <RouterLink
            :to="{ name: 'admin.analytics' }"
            class="group flex items-center gap-x-3 rounded-md fill-current p-2 text-sm font-semibold leading-6 text-gray-400 hover:bg-gray-800 hover:text-white focus:outline-none focus:ring-2 focus:ring-white"
          >
            <TableCellsLargeRegularIcon
              aria-hidden="true"
              class="h-5 w-5 shrink-0"
            />
            {{ $t("app.admin.title") }}
          </RouterLink>
        </ul>
      </template>
    </template>
  </SidebarLayout>
</template>

<script lang="ts" setup>
import SidebarLayout from "@/js/contexts/shared/ui/layouts/SidebarLayout.vue";
import LinkRegularIcon from "@/svg/icons/link-regular.svg?component";
import GaugeRegularIcon from "@/svg/icons/gauge-regular.svg?component";
import TableCellsLargeRegularIcon from "@/svg/icons/table-cells-large-regular.svg?component";
import useAuth from "@/js/contexts/auth/composables/useAuth";
import { Permission } from "@/js/contexts/shared/models/Permission";
import { computed } from "vue";

const { t } = useI18n();
const { hasPermission } = useAuth();

const navigation = computed(() =>
  [
    {
      name: t("app.dashboard.title"),
      to: { name: "dashboard" },
      icon: GaugeRegularIcon,
      hasPermission: hasPermission(Permission.DASHBOARD),
    },
    {
      name: t("app.links.title"),
      to: { name: "links" },
      icon: LinkRegularIcon,
      hasPermission: hasPermission(Permission.LINKS_VIEW, Permission.LINKS_CREATE, Permission.LINKS_UPDATE, Permission.LINKS_DELETE),
    },
  ].filter((item) => item.hasPermission),
);
</script>
